; 2600 programming for newbies
; Lesson 18 - Assymetrical Playfields Continued
;
; Objective: This program does many things:
;	1. Loads playfield data from a set of data tables.
;	The background the program creates is assymetrical 
;	so there are two sets of PF data for every scan line.
;	The tables are unoptimized. There are empty lines
;	full of zeroes which take valuable rom space.
;
;	2. Uses the sleep macro to skip cpu cycles so that
;	PF data for the right side of the screen is written 
;	at the right time.
;
;	3. Once every frame, the code increments
;	the playfield color to make the text graphics stand out.

	processor 6502
	include "vcs.h"
	include "macro.h"

	seg.u VARS
	org $80

PFColor	ds 1

	SEG
	org $F000

Reset

 ldx #0
 lda #0

Clear

 sta 0,x
 inx
 bne Clear

StartOfFrame

 lda #0
 sta VBLANK

 lda #2
 sta VSYNC

 sta WSYNC
 sta WSYNC
 sta WSYNC

 lda #0
 sta VSYNC

 ldx #0

VerticalBlank

 sta WSYNC
 inx
 cpx #37
 bne VerticalBlank

 ldx #0		; Init x to count scanlines

 lda #$84	; Set the PF color.
 sta COLUPF

ScanGo

 sta WSYNC	; Start counting cycles
		; Cycle counting could be wrong.
			
		; Loading left side PF data. This only takes
		; 19 cycles, well before the TIA starts drawing
		; this side of the screen.			
	
 lda PFData0A,x		; 4
 sta PF0		; 4 + 3
 lda PFData1A,x		; 7 + 4
 sta PF1		; 11 + 3
 lda PFData2A,x		; 12 + 4
 sta PF2		; 16 + 3 = 19

; Now if I didn't want to have the flashy banner
; I just need to uncomment the "sleep 10" line and
; comment out the four lines that follow.

; sleep 10		; 19 + 10

 cpx #135		; 19 + 2
 bne Continue		; 21 + 2

 iny			; 23 + 2
 sty COLUPF		; 25 + 3

nop


; Why am I color cycling here? Because it's the only
; place I found with enough free cpu cycles to do it.
; I am sure there are other solutions to it though.

Continue	
; Start loading right side PF Data.
; The sleep macro is used to make sure the PF registers
; are written when the TIA is not using them.

 lda PFData0B,x		; 28 + 4
 sta PF0		; 32 + 3
 
 sleep 4		; 35 + 4
 
 lda PFData1B,x		; 39 + 4
 sta PF1		; 43 + 3

 sleep 4		; 46 + 4

 lda PFData2B,x		; 50 + 4
 sta PF2		; 54 + 3

 inx			; 57 + 2
 cpx #192		; 59 + 2
 bne ScanGo		; 61 

EndFrame 

 lda #%01000010		
 sta VBLANK		
 ldx #0			

 sta WSYNC
 lda #$0A
 sta COLUBK
OverScan
 sta WSYNC
 inx
 cpx #29
 bne OverScan
 jmp StartOfFrame


;Assymetric Data 
;
; These tables cover every scanline on the screen.
; There are parts that are empty (full of 0's) that
; are taking valuable ROM space. However, it's OK
; since the program is only to learn how to do assymetrical
; playfields.

;Assymetric Data 

PFData0A

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData1A

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000001
    .byte #%00000001
    .byte #%00000111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00011111
    .byte #%00111111
    .byte #%00111111
    .byte #%00111111
    .byte #%00111111
    .byte #%00111111
    .byte #%00111111
    .byte #%01111110
    .byte #%01111100
    .byte #%01111110
    .byte #%01111100
    .byte #%11111100
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11111000
    .byte #%11110000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111000
    .byte #%11111100
    .byte #%01111100
    .byte #%01111100
    .byte #%01111110
    .byte #%01111110
    .byte #%00111111
    .byte #%00111111
    .byte #%00111111
    .byte #%00111111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00000111
    .byte #%00000111
    .byte #%00000011
    .byte #%00000011
    .byte #%00000001
    .byte #%00000001
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%01100000
    .byte #%01100000
    .byte #%11110000
    .byte #%11110000
    .byte #%10010000
    .byte #%10011000
    .byte #%11111000
    .byte #%11111000
    .byte #%10011000
    .byte #%10011000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000010
    .byte #%00000111
    .byte #%00001111
    .byte #%00001101
    .byte #%00011000
    .byte #%00011000
    .byte #%00011111
    .byte #%00011111
    .byte #%00011000
    .byte #%00011000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData2A

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111000
    .byte #%11111100
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%00011111
    .byte #%00011111
    .byte #%00000111
    .byte #%00000011
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11100000
    .byte #%11110000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%10110000
    .byte #%10110000
    .byte #%11111000
    .byte #%10111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111100
    .byte #%00111100
    .byte #%00011100
    .byte #%00011100
    .byte #%00011100
    .byte #%11011100
    .byte #%11011100
    .byte #%11011100
    .byte #%11011100
    .byte #%11011100
    .byte #%11011100
    .byte #%11011100
    .byte #%11001100
    .byte #%11001110
    .byte #%11001110
    .byte #%11101110
    .byte #%11100110
    .byte #%01100110
    .byte #%01100110
    .byte #%01100110
    .byte #%01100110
    .byte #%01100110
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%00110000
    .byte #%00110000
    .byte #%00110000
    .byte #%00110000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111000
    .byte #%00111100
    .byte #%00111100
    .byte #%00011100
    .byte #%00011100
    .byte #%00011100
    .byte #%00011100
    .byte #%00011100
    .byte #%00011100
    .byte #%00011100
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000001
    .byte #%00000001
    .byte #%00000011
    .byte #%00000011
    .byte #%00000111
    .byte #%00011111
    .byte #%01111111
    .byte #%01111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111111
    .byte #%11111100
    .byte #%11111000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000110
    .byte #%00000110
    .byte #%00011111
    .byte #%00011111
    .byte #%00000110
    .byte #%00000110
    .byte #%10000110
    .byte #%10000110
    .byte #%10011110
    .byte #%00011100
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11000001
    .byte #%11100001
    .byte #%00110011
    .byte #%00110011
    .byte #%00110011
    .byte #%00110011
    .byte #%11100011
    .byte #%11000011
    .byte #%00000000
    .byte #%11100000
    .byte #%11100000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData0B

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11010000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00010000
    .byte #%00010000
    .byte #%00010000
    .byte #%00010000
    .byte #%00110000
    .byte #%00110000
    .byte #%00110000
    .byte #%00110000
    .byte #%00110000
    .byte #%00110000
    .byte #%00110000
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%11110000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11000000
    .byte #%11010000
    .byte #%10010000
    .byte #%10010000
    .byte #%10110000
    .byte #%10110000
    .byte #%10110000
    .byte #%10110000
    .byte #%00110000
    .byte #%00110000
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%01110000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11000000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%11110000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11110000
    .byte #%11110000
    .byte #%00000000
    .byte #%11110000
    .byte #%11110000
    .byte #%00010000
    .byte #%11110000
    .byte #%11110000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%01010000
    .byte #%01110000
    .byte #%01100000
    .byte #%01100000
    .byte #%01100000
    .byte #%01100000
    .byte #%01110000
    .byte #%01110000
    .byte #%01100000
    .byte #%00110000
    .byte #%00110000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData1B

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%11100000
    .byte #%11110000
    .byte #%11111100
    .byte #%11111100
    .byte #%11111110
    .byte #%11111110
    .byte #%11111110
    .byte #%11111110
    .byte #%11111111
    .byte #%01111111
    .byte #%01111111
    .byte #%00111111
    .byte #%00111111
    .byte #%00011111
    .byte #%00011111
    .byte #%00001111
    .byte #%00001111
    .byte #%00000111
    .byte #%00001111
    .byte #%00001111
    .byte #%00000111
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%11000000
    .byte #%11000000
    .byte #%11000001
    .byte #%11000001
    .byte #%11000001
    .byte #%11100001
    .byte #%11100001
    .byte #%11100001
    .byte #%11100011
    .byte #%11100011
    .byte #%11100011
    .byte #%01100011
    .byte #%01100011
    .byte #%01000111
    .byte #%00000111
    .byte #%00000111
    .byte #%00001111
    .byte #%00001111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00111111
    .byte #%00111111
    .byte #%01111111
    .byte #%01111111
    .byte #%11111111
    .byte #%11111110
    .byte #%11111110
    .byte #%11111110
    .byte #%11111100
    .byte #%11111100
    .byte #%11111100
    .byte #%11111000
    .byte #%11111000
    .byte #%11110000
    .byte #%11100000
    .byte #%11100000
    .byte #%11100000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00001101
    .byte #%11001111
    .byte #%11001111
    .byte #%11001110
    .byte #%11001100
    .byte #%11001100
    .byte #%11001100
    .byte #%10001100
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00011100
    .byte #%00111110
    .byte #%01110011
    .byte #%01110011
    .byte #%01101111
    .byte #%01110000
    .byte #%00111111
    .byte #%00011110
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData2B

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000111
    .byte #%00000111
    .byte #%00000111
    .byte #%00000111
    .byte #%00000111
    .byte #%00000111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011110
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011110
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011110
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00011111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00001111
    .byte #%00000111
    .byte #%00000111
    .byte #%00000111
    .byte #%00000111
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000011
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000001
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00001100
    .byte #%00001100
    .byte #%00000000
    .byte #%00001101
    .byte #%00001101
    .byte #%00001101
    .byte #%00001100
    .byte #%00001100
    .byte #%00001100
    .byte #%00001100
    .byte #%00001100
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


	ORG $FFFA

InterruptVectors

	.word Reset 
	.word Reset 
	.word Reset 

 END


